==> sesameData_1.14.0.tar.gz: sesameData/inst/doc/sesameData.R <==
## ---- message=FALSE, warning=FALSE--------------------------------------------
library(sesameData)
library(GenomicRanges)

## -----------------------------------------------------------------------------
head(sesameDataList())

## ---- include = FALSE---------------------------------------------------------
sesameDataCacheExample()        # examples

## -----------------------------------------------------------------------------
sesameDataCache()

## -----------------------------------------------------------------------------
HM27.address <- sesameDataGet('HM27.address')

## -----------------------------------------------------------------------------
sesameDataGet_resetEnv()

## -----------------------------------------------------------------------------
txns_gr <- sesameData_getTxnGRanges("mm10")
txns_gr

## -----------------------------------------------------------------------------
genes_gr <- sesameData_txnToGeneGRanges(txns_gr)
genes_gr

## -----------------------------------------------------------------------------
probes <- names(sesameData_getManifestGRanges("Mammal40"))[1:500]
head(probes) # our input
txns <- sesameData_getTxnGRanges("hg38")
pm <- promoters(txns, upstream = 1500, downstream = 1500)
pm <- pm[pm$transcript_type == "protein_coding"]
sesameData_annoProbes(probes, pm, column = "gene_name")

## -----------------------------------------------------------------------------
gr <- sesameData_getManifestGRanges("HM450")
length(gr)

## ----message = FALSE, warning = FALSE-----------------------------------------
library(GenomicRanges)

## -----------------------------------------------------------------------------
regs <- GRanges('chr5', IRanges(135313937, 135419936))
sesameData_getProbesByRegion(regs, platform = 'Mammal40')
sesameData_getProbesByChromosome('chrX', platform = 'Mammal40')
sesameData_getAutosomeProbes("Mammal40")
sesameData_getProbesByGene('DNMT3A', "Mammal40", upstream=500)
sesameData_getProbesByTSS('DNMT3A', "Mammal40")

## -----------------------------------------------------------------------------
TSSprobes = sesameData_getProbesByTSS(NULL, "Mammal40")

## -----------------------------------------------------------------------------
sesameData_getGenesByProbes(c("cg14620903","cg22464003"), max_distance = 10000)

## ---- eval=FALSE--------------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly=TRUE))
#      install.packages("BiocManager")
#  BiocManager::install("sesameData")

## ---- eval=FALSE--------------------------------------------------------------
#  BiocManager::install("zwdzwd/sesameData")

## -----------------------------------------------------------------------------
sessionInfo()

==> sesameData_1.20.0.tar.gz: sesameData/inst/doc/sesameData.R <==
## ----message=FALSE, warning=FALSE---------------------------------------------
library(sesameData)
library(GenomicRanges)

## -----------------------------------------------------------------------------
head(sesameDataList())

## ----include = FALSE----------------------------------------------------------
sesameDataCacheExample()        # examples

## -----------------------------------------------------------------------------
sesameDataCache()

## -----------------------------------------------------------------------------
HM27.address <- sesameDataGet('HM27.address')

## -----------------------------------------------------------------------------
sesameDataGet_resetEnv()

## -----------------------------------------------------------------------------
txns_gr <- sesameData_getTxnGRanges("mm10")
txns_gr

## -----------------------------------------------------------------------------
genes_gr <- sesameData_txnToGeneGRanges(txns_gr)
genes_gr

## -----------------------------------------------------------------------------
probes <- names(sesameData_getManifestGRanges("Mammal40"))[1:500]
head(probes) # our input
txns <- sesameData_getTxnGRanges("hg38")
pm <- promoters(txns, upstream = 1500, downstream = 1500)
pm <- pm[pm$transcript_type == "protein_coding"]
sesameData_annoProbes(probes, pm, column = "gene_name")

## -----------------------------------------------------------------------------
gr <- sesameData_getManifestGRanges("HM450")
length(gr)

## ----message = FALSE, warning = FALSE-----------------------------------------
library(GenomicRanges)

## -----------------------------------------------------------------------------
regs <- GRanges('chr5', IRanges(135313937, 135419936))
sesameData_getProbesByRegion(regs, platform = 'Mammal40')
sesameData_getProbesByChromosome('chrX', platform = 'Mammal40')
sesameData_getAutosomeProbes("Mammal40")
sesameData_getProbesByGene('DNMT3A', "Mammal40", upstream=500)
sesameData_getProbesByTSS('DNMT3A', "Mammal40")

## -----------------------------------------------------------------------------
TSSprobes = sesameData_getProbesByTSS(NULL, "Mammal40")

## -----------------------------------------------------------------------------
sesameData_getGenesByProbes(c("cg14620903","cg22464003"), max_distance = 10000)

## ----eval=FALSE---------------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly=TRUE))
#      install.packages("BiocManager")
#  BiocManager::install("sesameData")

## ----eval=FALSE---------------------------------------------------------------
#  BiocManager::install("zwdzwd/sesameData")

## -----------------------------------------------------------------------------
sessionInfo()
